@@ -6,16 +6,11 @@ from qt_material import apply_stylesheet
 import networkx as nx
 
 # Temporary graph generation function
-def graph():
-    edge_list = []
-    edge_list.append( (1,2) )
-    edge_list.append( (1,3) )
-    edge_list.append( (2,4) )
-    edge_list.append( (3,4) )
-    edge_list.append( (4,5) )
-    edge_list.append( (2,5) )
+def graph1():
+    return nx.DiGraph([(1,2), (1,3), (2,4), (3,4), (4,5), (2,5)])
 
-    return nx.DiGraph(edge_list)
+def graph2():
+    return nx.DiGraph([(1,2), (1,3), (1,4)])
 
 if __name__ == "__main__":
 
@@ -25,7 +20,7 @@ if __name__ == "__main__":
     extra={ "secondaryDarkColor":"#232629", "font_size": '15px',}
     apply_stylesheet(app, theme='dark_blue.xml', extra=extra)
 
-    viewer = QGraphViewer(graph())
+    viewer = QGraphViewer({'graph1': graph1(), 'graph2':graph2()})
     viewer.show()
 
     sys.exit(app.exec())
